Module: JDDF
- Defined in:
- lib/jddf.rb,
lib/jddf/schema.rb,
lib/jddf/version.rb,
lib/jddf/validator.rb
Overview
Provides support for JSON Data Defintion Format (“JDDF”).
Defined Under Namespace
Classes: Discriminator, MaxDepthExceededError, Schema, ValidationError, Validator
Constant Summary collapse
- SCHEMA_KEYWORDS =
The keywords that may appear on a JDDF schema.
Each of these values correspond to an attribute available on Schema.
i[ definitions ref type enum elements properties optional_properties additional_properties values discriminator ].freeze
- DISCRIMINATOR_KEYWORDS =
The keywords that may appear on a JDDF schema discriminator object.
Each of these values correspond to an attribute available on Discriminator.
i[ tag mapping ].freeze
- TYPES =
The values the
typekeyword may take on in a JDDF schema.The
typeattribute of Schema has one of these values. i[ boolean int8 uint8 int16 uint16 int32 uint32 float32 float64 string ].freeze
- VERSION =
'0.2.1'